@@ -5,6 +5,7 @@ All rights reserved.
 This source code is licensed under the BSD-style license found in the LICENSE file in the root directory of this source tree.
 """
 
+
 # Add all custom exception classes here
 
 
@@ -24,3 +25,11 @@ class FileKeyError(Exception):
 
     def __str__(self):
         return f"Error -> {self.message}"
+
+
+class LoadChecksumError(Exception):
+    pass
+
+
+class LoadIncompatibleDB(Exception):
+    pass
