@@ -5,13 +5,32 @@ All rights reserved.
 This source code is licensed under the BSD-style license found in the LICENSE file in the root directory of this source tree.
 """
 
+from .lru import Cache_obj
+from .status import Status
+
+
+def is_pos(val):
+    return isinstance(val, int) and val > 0
+
+
 # Hash table operations
 
 
-def hnew(self, key):
+def hnew(self, key, max_age=None):
     if isinstance(key, str):
+        if max_age == None:
+            cache_obj = Cache_obj(key, self.max_age)
+        else:
+            if is_pos(max_age):
+                cache_obj = Cache_obj(key, max_age)
+            else:
+                raise Exception
+
+        if self.lru.push(cache_obj) == Status.FULL:
+            self.cull(self.cull_freq)  # Automatic cull
+            self.lru.push(cache_obj)
+
         self.db[key] = {}
-        self.lru.push(key)
         self._autocommit()
         return True
     else:
@@ -54,23 +73,34 @@ def hpop(self, key, dict_key):
 
 
 def hkeys(self, key):
-    self.lru.touch(key)
-    return self.db[key].keys()
+    if self.exists(key):
+        return self.db[key].keys()
+    else:
+        return None
 
 
 def hvals(self, key):
-    self.lru.touch(key)
-    return self.db[key].values()
+    if self.exists(key):
+        return self.db[key].values()
+    else:
+        return None
 
 
 def hexists(self, key, dict_key):
-    self.lru.touch(key)
-    return dict_key in self.db[key]
+    if self.exists(key):
+        if dict_key in self.db[key]:
+            return True
+        else:
+            return False
+    else:
+        return False
 
 
 def hmerge(self, key, new_dict):
-    self.lru.touch(key)
-    first = self.db[key]
-    first.update(new_dict)
-    self._autocommit()
-    return True
+    if self.exists(key):
+        first = self.db[key]
+        first.update(new_dict)
+        self._autocommit()
+        return True
+    else:
+        return False
