@@ -2,26 +2,26 @@
 
 import unittest
 import elara
+import os
 
 
 class RunTests(unittest.TestCase):
     def setUp(self):
         self.db = elara.exe("test.db", False)
 
-    def test_exe(self):
-        res = elara.exe("test.db", False)
-        assert res is not None
-
     def test_get(self):
+        self.db.clear()
         self.db.db["key"] = "test"
         res = self.db.db["key"]
         self.assertEqual(res, "test")
 
     def test_set(self):
+        self.db.clear()
         self.db.set("key", "test")
         self.assertEqual(self.db.get("key"), "test")
 
     def test_rem(self):
+        self.db.clear()
         self.db.set("key", "test")
         assert "key" in self.db.db
         self.db.rem("key")
@@ -33,6 +33,7 @@ class RunTests(unittest.TestCase):
         self.assertEqual(self.db.db, {})
 
     def test_cull(self):
+        self.db.clear()
         self.db.set("one", 1)
         self.db.set("two", 2)
         self.db.set("three", 3)
@@ -45,6 +46,7 @@ class RunTests(unittest.TestCase):
         self.assertEqual(self.db.cull(101), False)
 
     def test_incr(self):
+        self.db.clear()
         self.db.set("one", 1)
         self.db.incr("one")
         self.assertEqual(self.db.get("one"), 2)
@@ -56,6 +58,7 @@ class RunTests(unittest.TestCase):
         self.assertEqual(self.db.get("one"), 4.600)
 
     def test_decr(self):
+        self.db.clear()
         self.db.set("one", 1.35)
         self.db.decr("one")
         self.assertEqual(self.db.get("one"), 0.35)
